<template>
  <view class="page pt-2">
    <CardTitle title="拉丝自检" :hideAction="true" @action="addReport" />
    <view class="list">
      <wd-card type="rectangle" custom-class="round">
        <template #title>
          <view class="flex justify-between">
            <view>
              <wd-icon name="a-rootlist" color="#0D867F"></wd-icon>
              <text class="text-[#252525] ml-2 font-medium">自检项目名称</text>
            </view>
            <view class="text-[#A8A8A8]" @click="toEdit">编辑</view>
          </view>
        </template>
        <ProductionCard :data="cardAttr" color="#0D867F" />
      </wd-card>
    </view>
    <wd-popup v-model="dialog.visible" position="bottom" custom-class="yl-popup">
      <view class="action px-3">
        <wd-button type="text" @click="cancel">取消</wd-button>
        <wd-button type="text" @click="submit">确定</wd-button>
      </view>
      <SelfInspectForm />
    </wd-popup>
    <wd-toast />
  </view>
</template>

<script setup lang="ts">
import CardTitle from "@/components/card-title/index.vue";
import ProductionCard from "../components/ProductionCard.vue";
import { useToast } from "wot-design-uni";
import SelfInspectForm from "./form.vue";

const toast = useToast();
const dialog = reactive({
  visible: false,
});
const cardAttr = ref<any[]>([
  {
    label: "单位",
    value: "nΩ·m",
  },
  {
    label: "标准值",
    value: "1246",
  },
  {
    label: "自检值",
    value: "1245",
  },
  {
    label: "自检结果",
    value: "不合格",
    color: "#FF1E1E",
  },
]);
const addReport = () => {
  dialog.visible = true;
};

const toEdit = () => {
  uni.navigateTo({
    url: "/pages/production/selfInspect/edit",
  });
};
const submit = () => {
  toast.show("提交");
  dialog.visible = false;
};

const cancel = () => {
  toast.show("取消");
  dialog.visible = false;
};
</script>

<style lang="scss" scoped>
.page {
  background: #f3f9f8;
  .list {
    height: calc(100vh - 120px);
    margin: 12px;
    overflow: scroll;

    :deep() {
      .round {
        border-radius: 4px;
      }
    }
  }
}

.action {
  display: flex;
  justify-content: space-between;
}
</style>
